<?php

namespace common\logic\Order\Order;

use common\logic\BaseManager;
use common\logic\Config\TaxRate\TaxRate;
use common\logic\Distribution\Distribution\Distribution;
use common\logic\Document\Document\Document;
use common\logic\Order\ProductOrder\ProductOrder;
use common\logic\Producer\Producer\Producer;
use common\logic\Product\Product\Product;
use common\logic\Subscription\Subscription\Subscription;
use common\logic\User\User\User;
use yii\db\Query;

/**
 * Solver :
 * @method string getFieldNameAmount($typeTotal = Order::AMOUNT_TOTAL, string $typeField = '')
 * @method float getOrderTotalVat(Order $order, string $typeTotal = Order::AMOUNT_TOTAL)
 * @method string|null getPaymentStatus(Order $order)
 * @method string getPointSaleSummary(Order $order)
 * @method string getOrderUsername(Order $order)
 * @method bool isLinkedToValidDocument(Order $order)
 * @method string getCommentReport(Order $order)
 * @method string getDateAsHtml(Order $order)
 * @method int countProducts(Order $order)
 * @method int getProductQuantityPieces(Product $product, array $orders)
 * @method int getProductQuantity(Product $product, array $orders, bool $ignoreCancel = false, string $unit = null)
 * @method string getHistoryClass(Order $order)
 * @method string getHistorySummary(Order $order)
 * @method string getLabelOrigin(Order $order, bool $withLabel = false)
 * @method float getOrderAmount(Order $order, string $type = Order::AMOUNT_TOTAL, bool $format = false)
 * @method float getOrderAmountWithTax(Order $order, string $type = Order::AMOUNT_TOTAL, bool $format = false)
 * @method bool isOrderStateOpen(Order $order)
 * @method bool isOrderStatePreparation(Order $order)
 * @method bool isOrderStateDelivered(Order $order)
 * @method bool isOrderBelongsToUser(Order $order, User $user = null)
 * @method string getDataJson(Order $order)
 *
 * Repository :
 * @method array defaultOptionsSearch()
 * @method Order|null findOneById(int $id)
 * @method array findBy(array $params = [], array $options = [])
 * @method array findByDistribution(Distribution $distribution, string $conditionAppend = '')
 * @method Order|null findOneLastOfYear(Producer $producer)
 * @method Query queryHistory(Producer $producer, User $user, string $type = 'incoming')
 * @method string getCartSummary(Order $order, $htmlFormat = true)
 * @method string getAmountSummary(Order $order)
 * @method string getState(Order $order)
 *
 * Builder :
 * @method Order instanciateOrder(Distribution $distribution)
 * @method Order createOrder(Distribution $distribution)
 * @method Order|null createOrderFromSubscription(Subscription $subscription, string $date, bool $force = false)
 * @method array createAllOrdersFromSubscriptions(string $date, bool $force = false)
 * @method array updateOrdersIncomingDistributionsFromSubscription(Subscription $subscription, bool $update = false)
 * @method int deleteOrdersIncomingDistributionsFromSubscription(Subscription $subscription, bool $deleteAfterDateEnd = false)
 * @method bool addProductOrdersFromSubscription(Order $order, Subscription $subscription)
 * @method void updateOrderFromSubscription(Order $order, Subscription $subscription)
 * @method void initOrderBaseFromSubscription(Order $order, Subscription $subscription)
 * @method void initOrderAutoPaymentFromSubscription(Order $order, Subscription $subscription)
 * @method void createUserPointSale(Order $order)
 * @method void initOrderCommentPointSale(Order $order)
 * @method void initOrder(Order $order, string $taxCalculationMethod = Document::TAX_CALCULATION_METHOD_DEFAULT)
 * @method void initOrderAmount(Order $order, string $taxCalculationMethod = Document::TAX_CALCULATION_METHOD_DEFAULT)
 * @method void addProductOrderWeight(Order $order, ProductOrder $productOrder)
 * @method void addProductOrderAmount(Order $order, string $typeTotal, ProductOrder $productOrder, string $taxCalculationMethod)
 * @method void addProductOrderVat(Order $order, string $typeTotal, float $priceTotalWithoutTax, TaxRate $taxRate, string $taxCalculationMethod)
 * @method void initOrderPaidAmount(Order $order)
 * @method void deleteOrder(Order $order, bool $force = false): bool
 * @method void processCredit(Order $order)
 * @method void updateOrderTillerSynchronization(Order $order)
 * @method void updateOrderStatus(Order $order, string $newStatus, string $origin)
 * @method void generateOrderReference(Order $order)
 * @method void updateOrderInvoicePrices(Order $order, array $params = [])
 */
class OrderManager extends BaseManager
{
    public function __construct()
    {
        $this->setContainer(new OrderContainer());
    }
}